@@ -23,16 +23,20 @@ def extract_text_from_html(main_links: List[str]) -> dict:
     """
     From HTML files to TXT files
 
-    >>> extract_text_from_html(MAIN_LINKS)
+    >>> texts = extract_text_from_html(MAIN_LINKS)
+    >>> len(texts)
+    4
+    >>> len(texts[MAIN_LINKS[0]])
+    39
 
     :param main_links:
     :return:
     """
     retrieved_texts = {}
     for main_link in main_links:
-        directory = main_link.split("/")[-1].split(".")[0]
+        directory = os.path.join(PACKDIR, "nib_augsburg", main_link.split("/")[-1].split(".")[0])
         retrieved_texts[main_link] = []
-        for i in range(len(os.listdir(directory))):
+        for i in range(1, len(os.listdir(directory))):
             filename = os.path.join(directory, str(i) + ".html")
             with open(filename, "r") as f:
                 text = f.read()
@@ -45,18 +49,20 @@ def read_txt(main_link: str) -> List:
     """
     TXT files to str
 
-    >>> read_txt(MAIN_LINKS[0])
+    >>> len(read_txt(MAIN_LINKS[0]))
 
     :param main_link:
     :return:
     """
     retrieved_texts = []
-    directory = "extracted_" + main_link.split("/")[-1].split(".")[0][:-3]
-    for i in range(1, len(os.listdir(directory))):
+    directory = os.path.join(PACKDIR, "nib_augsburg", "extracted_" + main_link.split("/")[-1].split(".")[0][:-3])
+    if not os.path.exists(directory):
+        raise FileExistsError("Run sigurd.nib_augsburg.nib_scripts.extract_tei_from_html() to use current function.")
+    for i in range(len(os.listdir(directory))):
         filename = os.path.join(directory, str(i) + ".txt")
         with codecs.open(filename, "r", encoding="utf-8") as f:
             text = f.read()
-            lines = [line.split("\t") for line in text.split("\n")]
+            lines = [line.split("\t") for line in text.split("\n") if line]
         retrieved_texts.append(lines)
     return retrieved_texts
 
@@ -173,14 +179,15 @@ def find_occurrences_in_text(text: List[List[List[str]]],
     Each occurrence has the following format: <chapter>-<line>-<half-line>-<word>.
 
     >>> text = read_tei(MAIN_LINKS[0])
-    >>> researched_tokens = read_names()["Siegfried"]
+    >>> researched_tokens = read_rivers()["Rhone"]
     >>> find_occurrences_in_text(text, researched_tokens)
+    ['31-410-1-2']
 
     :param text: A text is composed of chapters. A chapter is composed of lines. A line is composed of 2 half lines. A half line is a string.
     :param researched_tokens: list of tokens to be searched in the text.
     :return: list of positions in the text
     """
-    researched_tokens = [token.lower() for token in researched_tokens]
+    researched_tokens = [token for token in researched_tokens]
     return [f"{i+1}-{j+1}-{k+1}-{l+1}" for i, chapter in enumerate(text)
             for j, line in enumerate(chapter)
             for k, half_line in enumerate(line)
