@@ -25,6 +25,8 @@ def get_nib_txt():
     """
     2
 
+    >>> get_nib_txt()
+
     :return:
     """
     retrieved_nib = reader.extract_text_from_html(retrieval.MAIN_LINKS)
@@ -57,9 +59,14 @@ def get_nib_tei_semgents():
     print(text)
 
 
-if __name__ == "__main__":
-    get_nib_html()
+def extract_tei_from_html():
+    # get_nib_html()
     get_nib_txt()
     get_nib_tei()
     get_nib_tei_group_annotations()
     get_nib_tei_semgents()
+    # reformat.save_tei_reformat(retrieval.MAIN_LINKS, )
+
+
+if __name__ == "__main__":
+    extract_tei_from_html()
